/* See LICENSE file for copyright and license details. */

/* appearance */
static const unsigned int borderpx  = 2;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar            = 1;        /* 0 means no bar */
static const int topbar             = 1;        /* 0 means bottom bar */
static const char *fonts[]          = { "JetBrainsMono Medium NF:pixelsize=14:antialias=true:autohint=true" };
static const char white[]       = "#ffffff";
static const char black[]       = "#000000";
static const char mgray[]       = "#bbbbbb";
static const char *colors[][3]      = {
	/*               fg     bg     border   */
	[SchemeNorm] = { black, white, mgray },
	[SchemeSel]  = { white, black, black },
};

/* tagging */
static const char *tags[] = { "1", "2", "3", "4" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class     instance  title           tags mask  isfloating  monitor */
	{ "St",      NULL,     "pinentry",     0,         1,          -1 },
};

/* layout(s) */
static const float mfact     = 0.5;  /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 0;    /* 1 means respect size hints in tiled resizals */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[]=",      tile },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
	{ "[M]",      monocle },
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell and emacs commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }
#define EMACS(cmd) { .v = (const char*[]){ "/bin/emacsclient", "-ce", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */
static const char *dmenucmd[] = { "dmenu_run", NULL };
static const char *termcmd[]  = { "tmuxt" };

static Key keys[] = {
	/* modifier         key        function        argument */
	{ MODKEY,           XK_p,      spawn,          {.v = dmenucmd } },
	{ MODKEY|ShiftMask, XK_p,      spawn,          SHCMD("passmenu") },
	{ MODKEY|ShiftMask, XK_Return, spawn,          {.v = termcmd } },
	{ MODKEY,           XK_b,      togglebar,      {0} },
	{ MODKEY,           XK_j,      focusstack,     {.i = +1 } },
	{ MODKEY,           XK_k,      focusstack,     {.i = -1 } },
	{ MODKEY|ShiftMask, XK_j,      pushdown,       {0} },
	{ MODKEY|ShiftMask, XK_k,      pushup,         {0} },
	{ MODKEY,           XK_i,      incnmaster,     {.i = +1 } },
	{ MODKEY,           XK_d,      incnmaster,     {.i = -1 } },
	{ MODKEY,           XK_h,      setmfact,       {.f = -0.05} },
	{ MODKEY,           XK_l,      setmfact,       {.f = +0.05} },
	{ MODKEY,           XK_Return, zoom,           {0} },
	{ MODKEY,           XK_Tab,    view,           {0} },
	{ MODKEY|ShiftMask, XK_c,      killclient,     {0} },
	{ MODKEY,           XK_t,      setlayout,      {.v = &layouts[0]} },
	{ MODKEY,           XK_f,      setlayout,      {.v = &layouts[1]} },
	{ MODKEY,           XK_m,      setlayout,      {.v = &layouts[2]} },
	{ MODKEY,           XK_space,  setlayout,      {0} },
	{ MODKEY|ShiftMask, XK_space,  togglefloating, {0} },
	{ MODKEY,           XK_comma,  focusmon,       {.i = -1 } },
	{ MODKEY,           XK_period, focusmon,       {.i = +1 } },
	{ MODKEY|ShiftMask, XK_comma,  tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask, XK_period, tagmon,         {.i = +1 } },
	TAGKEYS(            XK_1,                      0)
	TAGKEYS(            XK_2,                      1)
	TAGKEYS(            XK_3,                      2)
	TAGKEYS(            XK_4,                      3)
	{ MODKEY,           XK_5,      view,           {.ui = ~0 } },
	{ MODKEY|ShiftMask, XK_5,      tag,            {.ui = ~0 } },
	{ MODKEY|ShiftMask, XK_q,      quit,           {0} },
	/***************************************************************/
	{ MODKEY|ControlMask, XK_Return, spawn, SHCMD("emacsclient -c") },
	{ MODKEY|ControlMask, XK_q,      spawn, EMACS("(progn (switch-to-buffer \"*scratch*\") (mu4e))") },
	{ MODKEY|ControlMask, XK_w,      spawn, EMACS("(acheam-irc)") },
	{ MODKEY|ControlMask, XK_e,      spawn, EMACS("(elfeed)") },
	{ MODKEY|ControlMask, XK_r,      spawn, EMACS("(acheam-calendar)") },
	{ MODKEY|ControlMask, XK_t,      spawn, EMACS("(progn (calc) (windmove-up) (delete-window))") },
	{ MODKEY|ControlMask, XK_u,      spawn, SHCMD("dweb uri") },
	{ MODKEY|ControlMask, XK_i,      spawn, SHCMD("dweb search") },
	{ MODKEY|ControlMask, XK_o,      spawn, SHCMD("dweb bookmark") },
	{ MODKEY|ControlMask, XK_p,      spawn, SHCMD("chorizo") },
	{ 0,                  XK_F7,     spawn, SHCMD("chorizo") },
	/***************************************************************/
	{ 0,           XF86XK_AudioLowerVolume,  spawn, SHCMD("amixer sset Master 5%-; pkill -RTMIN+10 dwmblocks") },
	{ 0,           XF86XK_AudioRaiseVolume,  spawn, SHCMD("amixer sset Master 5%+; pkill -RTMIN+10 dwmblocks") },
	{ 0,           XF86XK_AudioMute,         spawn, SHCMD("amixer sset Master toggle; pkill -RTMIN+10 dwmblocks") },
	{ 0,           XF86XK_MonBrightnessDown, spawn, SHCMD("brightnessctl set 5%-") },
	{ 0,           XF86XK_MonBrightnessUp,   spawn, SHCMD("brightnessctl set 5%+") },
	{ 0,           XF86XK_Sleep,             spawn, SHCMD("doas zzz") },
	{ ControlMask, XF86XK_Sleep,             spawn, SHCMD("slock") },
	/***************************************************************/
	{ MODKEY|ControlMask, XK_h, spawn, SHCMD("xdotool keyup h key --clearmodifiers Left") },
	{ MODKEY|ControlMask, XK_j, spawn, SHCMD("xdotool keyup j key --clearmodifiers Down") },
	{ MODKEY|ControlMask, XK_k, spawn, SHCMD("xdotool keyup k key --clearmodifiers Up") },
	{ MODKEY|ControlMask, XK_l, spawn, SHCMD("xdotool keyup l key --clearmodifiers Right") },
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

static const char *const autostart[] = {
	"hsetroot", "-solid", "#bbbbbb", NULL,
	"dwmblocks", NULL,
	"xmodmap", "/home/armaa/.config/xmodmap", NULL,
	"xcape", NULL,
	"redshift", "-l", "42.4:-71.3", "-t", "6500:2500", NULL,
	"emacs", "--daemon", NULL,
	"syncthing", NULL,
	NULL /* terminate */
};
